package java.io;

import java.nio.charset.CharsetDecoder;
import java.nio.charset.Charset;
import sun.nio.cs.StreamDecoder;

public class InputStreamReader extends Reader
{
    private final StreamDecoder sd;
    
    public InputStreamReader(InputStream in) {
        super(in);
        try {
            this.sd = StreamDecoder.forInputStreamReader(in, this, (String)null);
        }
        catch (UnsupportedEncodingException cause) {
            throw new Error(cause);
        }
    }
    
    public InputStreamReader(InputStream in, String charsetName) throws UnsupportedEncodingException {
        super(in);
        if (charsetName == null) {
            throw new NullPointerException("charsetName");
        }
        this.sd = StreamDecoder.forInputStreamReader(in, this, charsetName);
        return;
    }
    
    public InputStreamReader(InputStream in, Charset cs) {
        super(in);
        if (cs == null) {
            throw new NullPointerException("charset");
        }
        this.sd = StreamDecoder.forInputStreamReader(in, this, cs);
        return;
    }
    
    public InputStreamReader(InputStream in, CharsetDecoder dec) {
        super(in);
        if (dec == null) {
            throw new NullPointerException("charset decoder");
        }
        this.sd = StreamDecoder.forInputStreamReader(in, this, dec);
        return;
    }
    
    public String getEncoding() {
        return this.sd.getEncoding();
    }
    
    @Override
    public int read() throws IOException {
        return this.sd.read();
    }
    
    @Override
    public int read(char[] cbuf, int offset, int length) throws IOException {
        return this.sd.read(cbuf, offset, length);
    }
    
    @Override
    public boolean ready() throws IOException {
        return this.sd.ready();
    }
    
    @Override
    public void close() throws IOException {
        this.sd.close();
    }
}
